Coverage for src/hatch_ci/hooks.py: 90%

# Coverage for src/hatch_ci/hooks.py : 90%

## 10 statements 9 run 1 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 | from hatchling.plugin import hookimpl from hatch_ci.hook_build import CIBuildHook from hatch_ci.hook_version import CIVersionSource @hookimpl def hatch_register_version_source(): return CIVersionSource @hookimpl def hatch_register_build_hook(): return CIBuildHook